@@ -7,7 +7,11 @@ import yaml
 
 from .dataset_utils import count_classes_in_lab_dir, show_list_images, \
     show_class_images
-from . import os_com
+import sys
+if 'google.colab' in sys.modules:
+    from .colab_os_com import colab_os_com as os_com
+else:
+    from .non_colab_os_com import non_colab_os_com as os_com
 
 
 # print(f'{__file__}, {__name__}, {__package__}')
